=====
Usage
=====


This project provides a `DictReader` and `DictWriter` for [linear TSV](http://dataprotocols.org/linear-tsv/) files, inspired by the ones available in `csv.py`.

To use tsv2dict in a project::

	import tsv2dict




> **Note:** If your TSV files originate in excel and contains quotes, tabs, or newlines, you might be better served using `csv.py`'s implementation with [excel_tab](https://docs.python.org/3/library/csv.html#csv.excel_tab), or `pandas`.
